var indexSectionsWithContent = {
   "Functions": {
      "Symbols": false,
      "Numbers": false,
      "A": false,
      "B": false,
      "C": false,
      "D": false,
      "E": false,
      "F": false,
      "G": true,
      "H": false,
      "I": false,
      "J": false,
      "K": false,
      "L": false,
      "M": false,
      "N": false,
      "O": false,
      "P": false,
      "Q": false,
      "R": false,
      "S": false,
      "T": false,
      "U": false,
      "V": false,
      "W": false,
      "X": false,
      "Y": false,
      "Z": false
      },
   "Files": {
      "Symbols": false,
      "Numbers": false,
      "A": true,
      "B": true,
      "C": true,
      "D": false,
      "E": false,
      "F": true,
      "G": true,
      "H": true,
      "I": true,
      "J": true,
      "K": false,
      "L": true,
      "M": true,
      "N": false,
      "O": false,
      "P": true,
      "Q": false,
      "R": false,
      "S": true,
      "T": true,
      "U": false,
      "V": false,
      "W": true,
      "X": true,
      "Y": false,
      "Z": false
      },
   "Macros": {
      "Symbols": false,
      "Numbers": false,
      "A": false,
      "B": false,
      "C": false,
      "D": false,
      "E": false,
      "F": false,
      "G": true,
      "H": false,
      "I": false,
      "J": false,
      "K": false,
      "L": false,
      "M": false,
      "N": false,
      "O": false,
      "P": false,
      "Q": false,
      "R": false,
      "S": false,
      "T": false,
      "U": false,
      "V": false,
      "W": false,
      "X": false,
      "Y": false,
      "Z": false
      },
   "General": {
      "Symbols": false,
      "Numbers": true,
      "A": true,
      "B": true,
      "C": true,
      "D": false,
      "E": true,
      "F": true,
      "G": true,
      "H": true,
      "I": true,
      "J": true,
      "K": false,
      "L": true,
      "M": true,
      "N": false,
      "O": true,
      "P": true,
      "Q": false,
      "R": false,
      "S": true,
      "T": true,
      "U": false,
      "V": false,
      "W": true,
      "X": true,
      "Y": false,
      "Z": false
      },
   "Types": {
      "Symbols": false,
      "Numbers": false,
      "A": false,
      "B": false,
      "C": false,
      "D": false,
      "E": false,
      "F": false,
      "G": true,
      "H": false,
      "I": false,
      "J": false,
      "K": false,
      "L": false,
      "M": false,
      "N": false,
      "O": false,
      "P": false,
      "Q": false,
      "R": false,
      "S": false,
      "T": false,
      "U": false,
      "V": false,
      "W": false,
      "X": false,
      "Y": false,
      "Z": false
      },
   "Constants": {
      "Symbols": false,
      "Numbers": false,
      "A": false,
      "B": false,
      "C": false,
      "D": false,
      "E": false,
      "F": false,
      "G": true,
      "H": false,
      "I": false,
      "J": false,
      "K": false,
      "L": false,
      "M": false,
      "N": false,
      "O": false,
      "P": false,
      "Q": false,
      "R": false,
      "S": true,
      "T": false,
      "U": false,
      "V": false,
      "W": false,
      "X": false,
      "Y": false,
      "Z": false
      }
   }